rule selectMappedISBP:
	message: " Select only mapped ISBPS on new refseq"
	input: mapped=config['results']+'/1.filteredISBPs/sorted.bed', original=config['isbpBed']
	output: temp(config['results']+'/2.mappedISBPs/coordsOnQuery.bed')
	log: config['results']+'/2.mappedISBPs/coordsOnQuery.log'
	shell:
		"""
		cut -f 4 {input.mapped}|fgrep -wf - {input.original} |sort -k1,1 -k2,2n 1> {output} 2> {log}
		"""

rule keepMappedOnSameChrom:
	message: " Select Mapped ISBPs on same chromosome (or on unknown chromosome)"
	input: isbpOnQuery=config['results']+'/2.mappedISBPs/coordsOnQuery.bed', isbpOnTarget=config['results']+"/1.filteredISBPs/sorted.bed"
	output: temp(config['results']+'/2.mappedISBPs/OnSameChrom.bed')
	log: config['results']+'/2.mappedISBPs/OnSameChrom.log'
	shell:
		"""
		join -1 4 -2 4 <(sort -k4,4 {input.isbpOnQuery}) <(sort -k4,4 {input.isbpOnTarget})|sed "s/ /\t/g"|awk "{{if (tolower(\$2) == tolower(\$5)) {{print \$2,\$3,\$4,\$1}} }}" |sort -k1,1 -k2,2n |sed "s/ /\t/g"> {output}
		join -1 4 -2 4 <(sort -k4,4 {input.isbpOnQuery}) <(sort -k4,4 {input.isbpOnTarget})|sed "s/ /\t/g"|fgrep -i chrun | awk "{{print \$2,\$3,\$4,\$1}}" |sed "s/ /\t/g">> {output}
		sort -k1,1 -k2,2n {output} > toto && mv toto {output}
		"""

rule upstreamClosest:
	message: " Collect closest marker upstream of genes"
	input: annot=config['results']+"/1.features.bed", markers=config['results']+'/2.mappedISBPs/OnSameChrom.bed'
	output: temp(config['results']+'/2.closestbed/Upstream.txt')
	log: config['results']+"/2.closestbed/Upstream.log"
	shell:
		"""
		bedtools closest -k 5 -id -D ref -io -a {input.annot} -b {input.markers} 1> {output} 2> {log}
		"""

rule downstreamClosest:
	message: " Collect Downstream marker downstream of genes"
	input: annot=config['results']+"/1.features.bed", markers=config['results']+'/2.mappedISBPs/OnSameChrom.bed'
	output: temp(config['results']+'/2.closestbed/downstream.txt')
	log: config['results']+"/2.closestbed/downstream.log"
	shell:
		"""
		bedtools closest -k 5 -iu -D ref -io -a {input.annot} -b {input.markers} 1> {output} 2> {log}
		"""

rule splitPerChrom:
	message: "Split data per chromosome"
	input: 
		upstream=config['results']+'/2.closestbed/Upstream.txt',
		downstream=config['results']+'/2.closestbed/downstream.txt'
	output:
		splitUp=temp(config['results']+'/2.closestbed/{chrom}/upstream.txt'),
		splitDown=config['results']+'/2.closestbed/{chrom}/downstream.txt'
	params: chromPref='TraesCS{chrom}'
	log: config['results']+'/2.closestbed/{chrom}/split.log'
	shell:
		"""
		fgrep  {params.chromPref} {input.upstream} 1> {output.splitUp} 2> {log}
		fgrep  {params.chromPref} {input.downstream} 1> {output.splitDown} 2>> {log}
		"""
