rule grepGffFeature:
        message: " Collect selected features from GFF file"
        input: config['annotationQuery']
        params: config['featureType']
        output: temp(config['results']+"/1.features.bed")
        log: config['results']+"/1.grepGffFeature.log"
        shell:  
                """
                bin/gff2bed.sh {params} {input} 1> {output} 2> {log}
                """

rule splitGffPerChrom:
        message: "Split Gff Features per chromosome: current is {wildcards.chrom}"
        input: config['results']+"/1.features.bed"
        output: temp(config['results']+"/1.features/{chrom}.bed")
        log: config['results']+"/1.features/{chrom}.fgrep.log"
        params: "chr{chrom}"
        shell:  
                """
                fgrep  {params} {input} 1> {output} 2> {log}
                """

rule indexQuery:
	message: " Indexing Query fasta file using samtools faidx"
	input: config['queryFasta']
	output: config['queryFasta']+'.fai'
	shell: "samtools faidx {input}"

rule indexTarget:
	message: " Indexing Target fasta file using samtools faidx"
	input: config['targetFasta']
	output: config['targetFasta']+'.fai'
	shell: "samtools faidx {input}"

rule gmapIndexTarget:
	message: " Create Gmap Index for rescue"
	input: config['targetFasta']
	output: directory(config['results']+"/target_gmapindex")
	params: indexname="target_gmapindex", indexPath=config['results']
	log: config['results']+"/target_gmapindex.log"
	shell: "gmap_build -D {params.indexPath} -d {params.indexname} {input} &> {log}"
