rule filterBam:
	message: "Filtering BAM file of ISBPs"
	input: config['isbpBam']
	output: config['results']+'/1.filteredISBPs.bam'
	params: mapq=config['mapq'], mismatches=config['mismatches']
	log: config['results']+'/1.filterBam.log'
	shell: "bin/filterBam.py {input} {output} {params.mapq} {params.mismatches} &> {log}"

rule bam2bed:
	message: "Convert Filtered BAM file into BED"
	input: config['results']+"/1.filteredISBPs.bam"
	output: temp(config['results']+"/1.filteredISBPs.bed")
	log: config['results']+"/2.bam2bed.log"
	shell: "bamToBed -i {input} 1> {output} 2> {log}"

rule sortBed:
	message: "Sort ISBPs bed file"
	input: config['results']+"/1.filteredISBPs.bed"
	output: temp(config['results']+"/1.filteredISBPs/sorted.bed")
	log: config['results']+'/1.sortBed.log'
	shell: "sort -k1,1 -k2,2n {input} 1> {output} 2> {log}"

rule dumpISBPsID:
	message: "Dump ISBPs IDs"
	input: config['results']+"/1.filteredISBPs/sorted.bed"
	output: temp(config['results']+"/1.filteredISBPs.ids")
	shell: " cut -f 4 {input} > {output}"

rule splitISBP:
	message: "Split isbps per chromosome"
	input: config['results']+"/1.filteredISBPs/sorted.bed"
	output: temp(config['results']+"/1.filteredISBPs/{chrom}/sorted.bed")
	log: config['results']+"/1.filteredISBPs/{chrom}/sorted.log"
	params: 'Chr{chrom}'
	shell:
		"""
		fgrep -i {params} {input} 1> {output} 2> {log}
		"""
